==> com.liferay.app.builder.web-1.0.2.jar: META-INF/resources/js/pages/form-view/saveFormView.es.js <==
Liferay.Loader.define("app-builder-web@1.0.2/js/pages/form-view/saveFormView.es", ['module', 'exports', 'require', '../../utils/client.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _client = require("../../utils/client.es");

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(source, true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(source).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  var _default = function _default(_ref) {
    var dataDefinition = _ref.dataDefinition,
        dataDefinitionId = _ref.dataDefinitionId,
        dataLayout = _ref.dataLayout,
        dataLayoutId = _ref.dataLayoutId;

    var normalizedDataLayout = _objectSpread({}, dataLayout, {
      dataLayoutPages: dataLayout.dataLayoutPages.map(function (dataLayoutPage) {
        return _objectSpread({}, dataLayoutPage, {
          dataLayoutRows: (dataLayoutPage.dataLayoutRows || []).map(function (dataLayoutRow) {
            return _objectSpread({}, dataLayoutRow, {
              dataLayoutColumns: (dataLayoutRow.dataLayoutColumns || []).map(function (dataLayoutColumn) {
                return _objectSpread({}, dataLayoutColumn, {
                  fieldNames: dataLayoutColumn.fieldNames || []
                });
              })
            });
          }),
          description: dataLayoutPage.description || _defineProperty({}, themeDisplay.getLanguageId(), ''),
          title: dataLayoutPage.title || _defineProperty({}, themeDisplay.getLanguageId(), '')
        });
      })
    });

    var updateDefinition = function updateDefinition() {
      return (0, _client.updateItem)("/o/data-engine/v2.0/data-definitions/".concat(dataDefinitionId), dataDefinition);
    };

    if (dataLayoutId) {
      return updateDefinition().then(function () {
        return (0, _client.updateItem)("/o/data-engine/v2.0/data-layouts/".concat(dataLayoutId), normalizedDataLayout);
      });
    }

    return updateDefinition().then(function () {
      return (0, _client.addItem)("/o/data-engine/v2.0/data-definitions/".concat(dataDefinitionId, "/data-layouts"), normalizedDataLayout);
    });
  };

  exports["default"] = _default;
  //# sourceMappingURL=saveFormView.es.js.map
});
//# sourceMappingURL=saveFormView.es.js.map

==> com.liferay.app.builder.web-1.0.18.jar: META-INF/resources/js/pages/form-view/saveFormView.es.js <==
Liferay.Loader.define("app-builder-web@1.0.18/js/pages/form-view/saveFormView.es", ['module', 'exports', 'require', '../../utils/client.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _client = require("../../utils/client.es");

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(Object(source), true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(Object(source)).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  var _default = function _default(_ref) {
    var dataDefinition = _ref.dataDefinition,
        dataDefinitionId = _ref.dataDefinitionId,
        dataLayout = _ref.dataLayout,
        dataLayoutId = _ref.dataLayoutId;

    var normalizedDataLayout = _objectSpread({}, dataLayout, {
      dataLayoutPages: dataLayout.dataLayoutPages.map(function (dataLayoutPage) {
        return _objectSpread({}, dataLayoutPage, {
          dataLayoutRows: (dataLayoutPage.dataLayoutRows || []).map(function (dataLayoutRow) {
            return _objectSpread({}, dataLayoutRow, {
              dataLayoutColumns: (dataLayoutRow.dataLayoutColumns || []).map(function (dataLayoutColumn) {
                return _objectSpread({}, dataLayoutColumn, {
                  fieldNames: dataLayoutColumn.fieldNames || []
                });
              })
            });
          }),
          description: dataLayoutPage.description || _defineProperty({}, themeDisplay.getLanguageId(), ''),
          title: dataLayoutPage.title || _defineProperty({}, themeDisplay.getLanguageId(), '')
        });
      })
    });

    var updateDefinition = function updateDefinition() {
      return (0, _client.updateItem)("/o/data-engine/v2.0/data-definitions/".concat(dataDefinitionId), dataDefinition);
    };

    if (dataLayoutId) {
      return updateDefinition().then(function () {
        return (0, _client.updateItem)("/o/data-engine/v2.0/data-layouts/".concat(dataLayoutId), normalizedDataLayout);
      });
    }

    return updateDefinition().then(function () {
      return (0, _client.addItem)("/o/data-engine/v2.0/data-definitions/".concat(dataDefinitionId, "/data-layouts"), normalizedDataLayout);
    });
  };

  exports["default"] = _default;
  //# sourceMappingURL=saveFormView.es.js.map
});
//# sourceMappingURL=saveFormView.es.js.map
